@@ -55,6 +55,7 @@ is_model <- function(x) {
       "brglmFit",
       "brmsfit",
       "brmultinom",
+      "bsem",
       "btergm",
       "cch",
       "censReg",
@@ -71,6 +72,7 @@ is_model <- function(x) {
       "confusionMatrix",
       "coxme",
       "coxph",
+      "coxph.penal",
       "cpglm",
       "cpglmm",
       "crch",
@@ -144,10 +146,12 @@ is_model <- function(x) {
       "lmerModLmerTest",
       "logitmfx",
       "logitor",
+      "lqm",
       "lqmm",
       "lrm",
       "manova",
       "MANOVA",
+      "margins",
       "maxLik",
       "mboostLSS",
       "mclogit",
@@ -161,10 +165,12 @@ is_model <- function(x) {
       "meta_random",
       "meta_ordered",
       "metaplus",
+      "mipo",
       "mixed",
       "mixor",
       "MixMod",
       "mjoint",
+      "mle",
       "mle2",
       "mlm",
       "mlogit",
