@@ -75,6 +75,7 @@ supported_models <- function() {
     "complmrob",
     "coxme",
     "coxph",
+    "coxph.penal",
     "cpglm",
     "cpglmm",
     "crch",
@@ -122,6 +123,8 @@ supported_models <- function() {
     "logitor",
     "logistf",
     "LORgee",
+    "lqm",
+    "lqmm",
     "lrm",
     "manova",
     "MANOVA",
@@ -130,9 +133,12 @@ supported_models <- function() {
     "MCMCglmm",
     "metaplus",
     "merMod",
+    "mipo",
     "mixed",
     "mixor",
     "MixMod",
+    "mle",
+    "mle2",
     "mlm",
     "mclogit",
     "mlogit",
@@ -155,6 +161,7 @@ supported_models <- function() {
     "robmixglm",
     "rq",
     "rqss",
+    "sem",
     "speedlm",
     "speedglm",
     "stanmvreg",
