@@ -94,6 +94,27 @@ n_obs.lmRob <- function(x, ...) {
 
 
 
+#' @export
+n_obs.lqmm <- function(x, ...) {
+  x$nobs
+}
+
+#' @export
+n_obs.lqm <- n_obs.lqmm
+
+
+
+
+#' @export
+n_obs.sem <- function(x, ...) {
+  if (!.is_semLme(x)) {
+    return(NULL)
+  }
+  length(x$original.y)
+}
+
+
+
 #' @export
 n_obs.LORgee <- function(x, ...) {
   x$nobs
@@ -165,6 +186,16 @@ n_obs.glimML <- function(x, ...) {
 
 
 
+#' @export
+n_obs.mle2 <- function(x, ...) {
+  nrow(get_data(x))
+}
+
+#' @export
+n_obs.mle <- n_obs.mle2
+
+
+
 #' @export
 n_obs.glmRob <- function(x, ...) {
   length(x$fitted.values)
@@ -401,3 +432,14 @@ n_obs.poissonirr <- n_obs.betamfx
 
 #' @export
 n_obs.logitor <- n_obs.betamfx
+
+
+
+
+
+# special models -----------
+
+#' @export
+n_obs.mipo <- function(x, ...) {
+  x$glanced$nobs
+}
