@@ -138,7 +138,7 @@ if (require("testthat") &&
     )
     expect_equal(nrow(get_parameters(m1)), 6)
     expect_equal(
-      get_parameters(m1)$parameter,
+      get_parameters(m1)$Parameter,
       c(
         "marry",
         "enrol",
